@@ -5,6 +5,8 @@
 */
 
 #include "sieveeditorconfiguredialog.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "sieveeditorconfigureserverwidget.h"
 #include "sieveeditorglobalconfig.h"
 #include <PimCommon/ConfigureImmutableWidgetUtils>
@@ -54,11 +56,11 @@ SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
 
     // Editor page
     auto editorWidget = new QWidget;
-    editorWidget->setObjectName(QLatin1StringView("editorwidget"));
+    editorWidget->setObjectName("editorwidget"_L1);
 
     layout = new QVBoxLayout(editorWidget);
     mWrapText = new QCheckBox(i18n("Wrap Text"));
-    mWrapText->setObjectName(QLatin1StringView("wraptext"));
+    mWrapText->setObjectName("wraptext"_L1);
     layout->addWidget(mWrapText);
     layout->addStretch(100);
 
@@ -69,7 +71,7 @@ SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
     // UserFeedBack config
 #ifdef WITH_KUSERFEEDBACK
     auto userFeedBackWidget = new QWidget;
-    userFeedBackWidget->setObjectName(QLatin1StringView("userFeedBackWidget"));
+    userFeedBackWidget->setObjectName("userFeedBackWidget"_L1);
 
     mUserFeedbackWidget = new KUserFeedback::FeedbackConfigWidget(this);
 
@@ -114,14 +116,14 @@ void SieveEditorConfigureDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(mySieveEditorConfigureDialog));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(mySieveEditorConfigureDialog));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SieveEditorConfigureDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(mySieveEditorConfigureDialog));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(mySieveEditorConfigureDialog));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
