@@ -5,6 +5,8 @@
 */
 
 #include "sieveeditormainwidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "sieveeditoremptytabwidgetlabel.h"
 #include "sieveeditorpagewidget.h"
 #include "sieveeditorscriptmanagerwidget.h"
@@ -30,7 +32,7 @@ SieveEditorMainWidget::SieveEditorMainWidget(KActionCollection *ac, QWidget *par
     : QSplitter(parent)
 {
     mStackedWidget = new QStackedWidget(this);
-    mStackedWidget->setObjectName(QLatin1StringView("stackedwidget"));
+    mStackedWidget->setObjectName("stackedwidget"_L1);
 
     mEditorEmptyLabel = new SieveEditorEmptyTabWidgetLabel;
 
@@ -54,7 +56,7 @@ SieveEditorMainWidget::SieveEditorMainWidget(KActionCollection *ac, QWidget *par
     setChildrenCollapsible(false);
     QList<int> splitterSizes;
     splitterSizes << 80 << 20;
-    KConfigGroup myGroup(KSharedConfig::openStateConfig(), QLatin1String(mySieveEditorMainWidgetConfigGroupName));
+    KConfigGroup myGroup(KSharedConfig::openStateConfig(), QLatin1StringView(mySieveEditorMainWidgetConfigGroupName));
     setSizes(myGroup.readEntry("mainSplitter", splitterSizes));
     updateStackedWidget();
 }
@@ -62,7 +64,7 @@ SieveEditorMainWidget::SieveEditorMainWidget(KActionCollection *ac, QWidget *par
 SieveEditorMainWidget::~SieveEditorMainWidget()
 {
     disconnect(mScriptManagerWidget, &SieveEditorScriptManagerWidget::updateButtons, this, &SieveEditorMainWidget::updateButtons);
-    KConfigGroup myGroup(KSharedConfig::openStateConfig(), QLatin1String(mySieveEditorMainWidgetConfigGroupName));
+    KConfigGroup myGroup(KSharedConfig::openStateConfig(), QLatin1StringView(mySieveEditorMainWidgetConfigGroupName));
     myGroup.writeEntry("mainSplitter", sizes());
     myGroup.sync();
 }
